==> open-xchange-subscribe-crawler_6.16.1.0.orig.tar.gz: open-xchange-subscribe-crawler-6.16.1.0/src/com/openexchange/subscribe/crawler/internal/Step.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.crawler.internal;

import java.lang.reflect.TypeVariable;
import com.gargoylesoftware.htmlunit.WebClient;
import com.openexchange.subscribe.SubscriptionException;
import com.openexchange.subscribe.crawler.Workflow;

/**
 * A Step in a crawling workflow
 * 
 * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
 * @param <O> The Output accessible if the step executed successfully
 * @param <I> The Input needed for the step to execute
 */
public interface Step<O, I>{

    boolean executedSuccessfully();

    Exception getException();

    void execute(WebClient webClient) throws SubscriptionException;

    Class inputType();

    Class outputType();
    
    void setWorkflow(Workflow workflow);
    
    public void setInput(I input);
    
    public O getOutput();
    
    public boolean isDebuggingEnabled();
    
    public void setDebuggingEnabled(boolean debuggingEnabled);
    
    public TypeVariable<?>[] runEmpty();

}

==> open-xchange-subscribe-crawler_6.20.8.0.orig.tar.gz: open-xchange-subscribe-crawler-6.20.8.0/src/com/openexchange/subscribe/crawler/internal/Step.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.crawler.internal;

import java.lang.reflect.TypeVariable;
import com.gargoylesoftware.htmlunit.WebClient;
import com.openexchange.subscribe.SubscriptionException;
import com.openexchange.subscribe.crawler.Workflow;

/**
 * A Step in a crawling workflow
 * 
 * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
 * @param <O> The Output accessible if the step executed successfully
 * @param <I> The Input needed for the step to execute
 */
public interface Step<O, I>{

    boolean executedSuccessfully();

    Exception getException();

    void execute(WebClient webClient) throws SubscriptionException;

    Class inputType();

    Class outputType();
    
    void setWorkflow(Workflow workflow);
    
    public void setInput(I input);
    
    public I getInput();
    
    public O getOutput();
    
    public boolean isDebuggingEnabled();
    
    public void setDebuggingEnabled(boolean debuggingEnabled);
    
    public TypeVariable<?>[] runEmpty();

    public boolean isSwitchUserAgent();

    public void setSwitchUserAgent(boolean switchUserAgent);

}
